# ALgorithmic COmposition KIT (alcokit)
This is a small library for performing various tasks on musical data in the frequency domain. The goal of `alcokit` is to offer practical abstractions to programming composers and musicians.  

Available functionalities range from time-segmentation and polyphonic pitch detection to efficient hdf5 storage and sequence modeling.

`alcokit` is still in early development. Documentation and use-case examples are coming soon...   